==> core_models-0.1.0.gem: app/controllers/core_models/people_and_companies/job_titles_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class PeopleAndCompanies::JobTitlesController < CoreModelsController
    # GET /people_and_companies/job_titles
    # GET /people_and_companies/job_titles.json
    def index
      @people_and_companies_job_titles = PeopleAndCompanies::JobTitle.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @people_and_companies_job_titles }
      end
    end

    # GET /people_and_companies/job_titles/1
    # GET /people_and_companies/job_titles/1.json
    def show
      @people_and_companies_job_title = PeopleAndCompanies::JobTitle.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @people_and_companies_job_title }
      end
    end

    # GET /people_and_companies/job_titles/new
    # GET /people_and_companies/job_titles/new.json
    def new
      @people_and_companies_job_title = PeopleAndCompanies::JobTitle.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @people_and_companies_job_title }
      end
    end

    # GET /people_and_companies/job_titles/1/edit
    def edit
      @people_and_companies_job_title = PeopleAndCompanies::JobTitle.find(params[:id])
    end

    # POST /people_and_companies/job_titles
    # POST /people_and_companies/job_titles.json
    def create
      @people_and_companies_job_title = PeopleAndCompanies::JobTitle.new(params[:people_and_companies_job_title])

      respond_to do |format|
        if @people_and_companies_job_title.save
          format.html { redirect_to @people_and_companies_job_title, :notice => 'Job title was successfully created.' }
          format.json { render :json => @people_and_companies_job_title, :status => :created, :location => @people_and_companies_job_title }
        else
          format.html { render :action => "new" }
          format.json { render :json => @people_and_companies_job_title.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /people_and_companies/job_titles/1
    # PUT /people_and_companies/job_titles/1.json
    def update
      @people_and_companies_job_title = PeopleAndCompanies::JobTitle.find(params[:id])

      respond_to do |format|
        if @people_and_companies_job_title.update_attributes(params[:people_and_companies_job_title])
          format.html { redirect_to @people_and_companies_job_title, :notice => 'Job title was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @people_and_companies_job_title.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /people_and_companies/job_titles/1
    # DELETE /people_and_companies/job_titles/1.json
    def destroy
      @people_and_companies_job_title = PeopleAndCompanies::JobTitle.find(params[:id])
      @people_and_companies_job_title.destroy

      respond_to do |format|
        format.html { redirect_to people_and_companies_job_titles_url }
        format.json { head :no_content }
      end
    end
  end
end

==> core_models-0.2.9.gem: app/controllers/core_models/people_and_companies/job_titles_controller.rb <==
require_dependency "core_models/core_models_controller"

module CoreModels
  class PeopleAndCompanies::JobTitlesController < CoreModelsController
    # GET /people_and_companies/job_titles
    # GET /people_and_companies/job_titles.json
    def index
      @people_and_companies_job_titles = PeopleAndCompanies::JobTitle.all

      respond_to do |format|
        format.html # index.html.erb
        format.json { render :json => @people_and_companies_job_titles }
      end
    end

    # GET /people_and_companies/job_titles/1
    # GET /people_and_companies/job_titles/1.json
    def show
      @people_and_companies_job_title = PeopleAndCompanies::JobTitle.find(params[:id])

      respond_to do |format|
        format.html # show.html.erb
        format.json { render :json => @people_and_companies_job_title }
      end
    end

    # GET /people_and_companies/job_titles/new
    # GET /people_and_companies/job_titles/new.json
    def new
      @people_and_companies_job_title = PeopleAndCompanies::JobTitle.new

      respond_to do |format|
        format.html # new.html.erb
        format.json { render :json => @people_and_companies_job_title }
      end
    end

    # GET /people_and_companies/job_titles/1/edit
    def edit
      @people_and_companies_job_title = PeopleAndCompanies::JobTitle.find(params[:id])
    end

    # POST /people_and_companies/job_titles
    # POST /people_and_companies/job_titles.json
    def create
      @people_and_companies_job_title = PeopleAndCompanies::JobTitle.new(params[:people_and_companies_job_title])

      respond_to do |format|
        if @people_and_companies_job_title.save
          format.html { redirect_to @people_and_companies_job_title, :notice => 'Job title was successfully created.' }
          format.json { render :json => @people_and_companies_job_title, :status => :created, :location => @people_and_companies_job_title }
        else
          format.html { render :action => "new" }
          format.json { render :json => @people_and_companies_job_title.errors, :status => :unprocessable_entity }
        end
      end
    end

    # PUT /people_and_companies/job_titles/1
    # PUT /people_and_companies/job_titles/1.json
    def update
      @people_and_companies_job_title = PeopleAndCompanies::JobTitle.find(params[:id])

      respond_to do |format|
        if @people_and_companies_job_title.update(params[:people_and_companies_job_title])
          format.html { redirect_to @people_and_companies_job_title, :notice => 'Job title was successfully updated.' }
          format.json { head :no_content }
        else
          format.html { render :action => "edit" }
          format.json { render :json => @people_and_companies_job_title.errors, :status => :unprocessable_entity }
        end
      end
    end

    # DELETE /people_and_companies/job_titles/1
    # DELETE /people_and_companies/job_titles/1.json
    def destroy
      @people_and_companies_job_title = PeopleAndCompanies::JobTitle.find(params[:id])
      @people_and_companies_job_title.destroy

      respond_to do |format|
        format.html { redirect_to people_and_companies_job_titles_url }
        format.json { head :no_content }
      end
    end
  end
end
